==> haskell-adjunctions-4.3-5-armv7h.pkg.tar.xz: usr/share/haskell/haskell-adjunctions/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: adjunctions
version: 4.3
id: adjunctions-4.3-4ea5517ab8878ad5d6d1874f8242d7cd
key: adjun_BfkyfjtqRdK2S8HPcjqDko
license: BSD3
copyright: Copyright (C) 2011-2014 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: provisional
homepage: http://github.com/ekmett/adjunctions/
synopsis: Adjunctions and representable functors
description:
    Adjunctions and representable functors
category: Data Structures, Adjunctions
author: Edward A. Kmett
exposed: True
exposed-modules:
    Control.Comonad.Representable.Store Control.Comonad.Trans.Adjoint
    Control.Monad.Representable.Reader
    Control.Monad.Representable.State Control.Monad.Trans.Adjoint
    Control.Monad.Trans.Contravariant.Adjoint Control.Monad.Trans.Conts
    Data.Functor.Adjunction Data.Functor.Contravariant.Adjunction
    Data.Functor.Contravariant.Rep Data.Functor.Rep
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/adjunctions-4.3
library-dirs: /usr/lib/ghc-7.10.3/site-local/adjunctions-4.3
data-dir: /usr/share/arm-linux-ghc-7.10.3/adjunctions-4.3
hs-libraries: HSadjunctions-4.3-BfkyfjtqRdK2S8HPcjqDko
depends:
    array-0.5.1.0-a4b4f31b03b7779670557ea46745a386
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    comonad-5-9a3bede31f7f9dbe4efd0f02bc9ca766
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    contravariant-1.4-40742dd1a022cbf40c8c77a36d4f0610
    distributive-0.5.0.2-17a8848c95a42a5c612669379433d996
    free-4.12.4-00d655da7510c123b23f3d4ff9d2e676
    mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
    profunctors-5.2-9bddc68ddf0f4fcea803005a53816983
    semigroupoids-5.0.1-e4734876ceb621b0eefb491ac209dad3
    semigroups-0.18.1-34c490e60d2f8a8cae75b79e944c6c08
    tagged-0.8.3-aa128de4449752177a05765fb0ce3959
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    transformers-compat-0.5.1.4-b5340b5b89d4b4066d5de0d53e173907
    void-0.7.1-662e5f28c19568c0aec0b2de7532ac34
haddock-interfaces: /usr/share/doc/haskell-adjunctions/html/adjunctions.haddock
haddock-html: /usr/share/doc/haskell-adjunctions/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-adjunctions-4.3-6-armv7h.pkg.tar.xz: usr/share/haskell/haskell-adjunctions/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: adjunctions
version: 4.3
id: adjunctions-4.3-05e83bc618f3f68473cfebcb6bdadb51
key: adjun_HDsJYgzYdktElBtpAiTjFy
license: BSD3
copyright: Copyright (C) 2011-2014 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: provisional
homepage: http://github.com/ekmett/adjunctions/
synopsis: Adjunctions and representable functors
description:
    Adjunctions and representable functors
category: Data Structures, Adjunctions
author: Edward A. Kmett
exposed: True
exposed-modules:
    Control.Comonad.Representable.Store Control.Comonad.Trans.Adjoint
    Control.Monad.Representable.Reader
    Control.Monad.Representable.State Control.Monad.Trans.Adjoint
    Control.Monad.Trans.Contravariant.Adjoint Control.Monad.Trans.Conts
    Data.Functor.Adjunction Data.Functor.Contravariant.Adjunction
    Data.Functor.Contravariant.Rep Data.Functor.Rep
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/adjunctions-4.3
library-dirs: /usr/lib/ghc-7.10.3/site-local/adjunctions-4.3
data-dir: /usr/share/arm-linux-ghc-7.10.3/adjunctions-4.3
hs-libraries: HSadjunctions-4.3-HDsJYgzYdktElBtpAiTjFy
depends:
    array-0.5.1.0-a4b4f31b03b7779670557ea46745a386
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    comonad-5-530ea4e1d08a0115920b946124e760ac
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    contravariant-1.4-7b1149a75def92c79deb23a86e0b36cb
    distributive-0.5.0.2-17a8848c95a42a5c612669379433d996
    free-4.12.4-6ceee3b0778288ec7c5c8e8d64937985
    mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
    profunctors-5.2-1b9f80ec12ba976fbd92d616f7b33d0d
    semigroupoids-5.0.1-fafa53fc1a76ec617ee4419105d11368
    semigroups-0.18.1-4a4dee25d838ab8c8d38a0caa045cf78
    tagged-0.8.3-aa128de4449752177a05765fb0ce3959
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    transformers-compat-0.5.1.4-b5340b5b89d4b4066d5de0d53e173907
    void-0.7.1-5ad9ec6793ffb57ac26a200023a4290d
haddock-interfaces: /usr/share/doc/haskell-adjunctions/html/adjunctions.haddock
haddock-html: /usr/share/doc/haskell-adjunctions/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
